Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(r *Redialer)
Option to configure Reconnector.
func WithBackoff ¶
WithBackoff sets backoff function for reconnection. By default, uses backoff.NewExponentialBackOff.
func WithConfig ¶
WithConfig uses provided cfg to specify a configuration for the transport and connection setup used during a connection open handshake. See more: https://pkg.go.dev/github.com/rabbitmq/amqp091-go@v1.8.0#DialConfig.
func WithDialAttemptCallback ¶
WithDialAttemptCallback registers a callback for any AMQP dial attempt result. Will call func with result for each attempt to dial AMQP.
func WithDialledCallback ¶
func WithDialledCallback(fn func(*amqp.Connection)) Option
WithDialledCallback registers a callback for successful AMQP dial. Will call func with each created connection. Could be used to set up listeners for various evens (NotifyClose, NotifyFlow, etc.) after channel recreation.